# @anywidget/svelte

## 0.0.6

### Patch Changes

- Updated dependencies [[`777fc268ee06fcf13e48a1c00cfdf90c14d786dc`](https://github.com/manzt/anywidget/commit/777fc268ee06fcf13e48a1c00cfdf90c14d786dc)]:
  - @anywidget/types@0.1.7

## 0.0.5

### Patch Changes

- Updated dependencies [[`9aa8dcc8558e00e33fbe4506b68ae30113df3728`](https://github.com/manzt/anywidget/commit/9aa8dcc8558e00e33fbe4506b68ae30113df3728)]:
  - @anywidget/types@0.1.6

## 0.0.4

### Patch Changes

- Updated dependencies [[`6608992b8fe3a9f4eb7ebb2c8c5533febf26f4dd`](https://github.com/manzt/anywidget/commit/6608992b8fe3a9f4eb7ebb2c8c5533febf26f4dd)]:
  - @anywidget/types@0.1.5

## 0.0.3

### Patch Changes

- fix: broken import in WrapperComponent ([#219](https://github.com/manzt/anywidget/pull/219))

## 0.0.2

### Patch Changes

- feat: use JS Symbols to scope access to Svelte Context ([#215](https://github.com/manzt/anywidget/pull/215))

## 0.0.1

### Patch Changes

- feat: Use Context API to expose `model` and `stores` to components. ([#213](https://github.com/manzt/anywidget/pull/213))
